@@ -2,6 +2,7 @@ use crate::{ KyncError, CSource, AsCSource, CSink, AsCSink, ffi::{ CError, FromC
 use std::path::Path;
 use libloading::Library;
 use crate::ErrorKind;
+use std::os::raw::c_char;
 
 
 /// The current API version
@@ -31,7 +32,7 @@ pub fn os_default_suffix() -> &'static str {
 
 /// A key capsule plugin (see "Kync.asciidoc" for further API documentation)
 pub struct Plugin {
-	capsule_format_uid: unsafe extern "C" fn() -> *const u8,
+	capsule_format_uid: unsafe extern "C" fn() -> *const c_char,
 	
 	capsule_key_ids: unsafe extern "C" fn(id_buffer: CSink) -> CError,
 	
@@ -83,7 +84,7 @@ impl Plugin {
 	
 	/// The capsule format UID
 	pub fn capsule_format_uid(&self) -> String {
-		unsafe{ String::from_c_str_limit((self.capsule_format_uid)(), 64) }.unwrap()
+		unsafe{ String::from_c_str((self.capsule_format_uid)()) }.unwrap()
 	}
 	
 	/// The available capsule keys
